sqlobject.tests.test_class_hash module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_class_hash module

class `sqlobject.tests.test_class_hash.` `ClassHashTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `j` = class_hash_test
  property `name`
  `q` = class_hash_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_class_hash.ClassHashTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'class_hash_test'

`sqlobject.tests.test_class_hash.` `test_class_hash`()